unit Global;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, inifiles;

type
  TGlobal = class(TComponent)
  private
    { Private declarations }
    FText : string;
    FonErrorShowMessaage:Boolean;
    Finifilename, FiniSection : string;
    FOnChange : TNotifyEvent;
    procedure SetValue(Value : string);
  protected
    procedure iniRead; virtual;
    procedure iniWrite; virtual;
    procedure loaded; override;

    procedure DoChange;

  public
    constructor Create(AOwner : TComponent); override;
    destructor Destroy; override;
    function Asinteger : integer;
    function AsBoolean : Boolean;
    function AsFloat : Extended;
    function AsCurrency : Currency;
    function AsDate : TdateTime;
    function AsTime : TdateTime;
    function AsDateTime : TdateTime;

    { Public declarations }
  published
    property Text : string read FText write SetValue;
    property OnErrorShowMessaage:Boolean read FonErrorShowMessaage write FonErrorShowMessaage;
    property inifilename : string read FiniFileName write FiniFileName;
    property iniSection : string read FiniSection write FiniSection;
    property OnChange : TNotifyEvent read FOnChange write FOnChange;
    { Published declarations }
  end;

procedure Register;

implementation


constructor TGlobal.Create(AOwner : TComponent);
begin
  iniRead;
  Text := FText;
  onErrorShowMessaage:=FonErrorShowMessaage;
  inherited Create(AOwner);
end;

destructor TGlobal.Destroy;
begin
  iniWrite;
  inherited Destroy;
end;

procedure TGlobal.Loaded;
begin
  inherited Loaded;
  iniRead;
end;


procedure TGlobal.DoChange;
begin
  if Assigned(FOnChange) then FOnChange(self);
end;

procedure TGlobal.iniRead;
begin
  if inifilename = '' then exit;
  if inisection = '' then exit;
  with TIniFile.Create(inifilename) do
  try
    FText := ReadString(inisection, Name, Text);
    Text := FText;
  finally
    Free;
  end;
end;

procedure TGlobal.iniWrite;
begin
  if inifilename = '' then exit;
  if inisection = '' then exit;
  with TIniFile.Create(inifilename) do
  try
    WriteString(inisection, Name, Text);
  finally
    Free;
  end;
end;

procedure TGlobal.SetValue(Value : string);
begin
  if Value <> FText then
  begin
    FText := Value;
    Text := FText;
    dochange;
  end;
end;

function TGlobal.Asinteger : integer;
begin
  if FText = '' then result := 0 else
  try
    result := strtoint(FText);
  except

    if FonErrorShowMessaage then showmessage('Invalid string for integer : ' + FText);
    result := 0;
  end;
end;

function TGlobal.AsBoolean : Boolean;
begin
  if (uppercase(FText) = 'TRUE') then result := True
  else if (uppercase(FText) = 'FALSE') then result := False
  else
  begin
    if FonErrorShowMessaage then showmessage('Invalid string for Boolean :' + FText);
    result := False;
  end;
end;

function TGlobal.AsFloat : Extended;
begin
  try
    result := strtoFloat(FText);
  except
    if FonErrorShowMessaage then showmessage('Invalid string for Float:' + FText);
    result := 0.00;
  end;
end;

function TGlobal.AsCurrency : Currency;
begin
  try
    result := strtoCurr(FText);
  except
    if FonErrorShowMessaage then showmessage('Invalid string for Currency:' + FText);
    result := 0;
  end;
end;

function TGlobal.AsDate : TdateTime;
begin
  try
    result := strtoDate(FText);
  except
    if FonErrorShowMessaage then showmessage('Invalid string for Date:' + FText);
    result := 0;
  end;
end;

function TGlobal.AsTime : TdateTime;
begin
  try
    result := strtoTime(FText);
  except
    if FonErrorShowMessaage then showmessage('Invalid string for Time : ' + FText);
    result := 0;
  end;
end;

function TGlobal.AsDateTime : TdateTime;
begin
  try
    result := strtoDateTime(FText);
  except
    if FonErrorShowMessaage then showmessage('Invalid string for DateTime:' + FText);
    result := 0;
  end;
end;

procedure Register;
begin
  RegisterComponents('Samples', [TGlobal]);
end;

end.

